@@ -3,8 +3,9 @@ use warnings;
 
 package Test::Tester::Delegate;
 
-our $VERSION = '1.302064';
+our $VERSION = '1.302065';
 
+use Scalar::Util();
 
 use vars '$AUTOLOAD';
 
@@ -32,4 +33,13 @@ sub AUTOLOAD
 	goto &$ref;
 }
 
+sub can {
+	my $this = shift;
+	my ($sub) = @_;
+
+	return $this->{Object}->can($sub) if Scalar::Util::blessed($this);
+
+	return $this->SUPER::can(@_);
+}
+
 1;
